@@ -242,7 +242,7 @@ def get_share_type(share_type):
 
 
 def scci_cmd(host, userid, password, cmd, port=443, auth_method='basic',
-             client_timeout=60, async=True, **kwargs):
+             client_timeout=60, do_async=True, **kwargs):
     """execute SCCI command
 
     This function calls SCCI server modules
@@ -253,7 +253,7 @@ def scci_cmd(host, userid, password, cmd, port=443, auth_method='basic',
     :param port: port number of iRMC
     :param auth_method: irmc_username
     :param client_timeout: timeout for SCCI operations
-    :param async: async call if True, sync call otherwise
+    :param do_async: async call if True, sync call otherwise
     :returns: requests.Response from SCCI server
     :raises: SCCIInvalidInputError if port and/or auth_method params
              are invalid
@@ -282,12 +282,12 @@ def scci_cmd(host, userid, password, cmd, port=443, auth_method='basic',
                           timeout=client_timeout,
                           allow_redirects=False,
                           auth=auth_obj)
-        if not async:
+        if not do_async:
             time.sleep(5)
         if DEBUG:
             print(cmd)
             print(r.text)
-            print("async = %s" % async)
+            print("do_async = %s" % do_async)
         if r.status_code not in (200, 201):
             raise SCCIClientError(
                 ('HTTP PROTOCOL ERROR, STATUS CODE = %s' %
